pro lya_subtract, index, data,  $
                  iout, dout, $
                  shift = shift, $
                  debug = debug
;+
; NAME:
;    LYA_SUBTRACT.PRO
;
; PURPOSE:
;    Given a pair of 1216 + 1600 images, subtract the two with 
;    coefficients that follow to produce a "clean" Ly Alpha image.
;    Note that this routine does this in two steps:
;        (1) Gaussian smooth the 1600 image to reflect the 
;            corresponding focus through the 1216 filters, and ...
;        (2) Subtract.
; 
; CALLING SEQUENCE:
;    lya_subtract, index, data, iout, dout, $
;                 [,/debug]
; 
; INPUTS:
;    index, data -- data cube for the pair/triplet of images
;          --> NOTE: -->
;          The data is expected to meet the following minimum requirements:
;
;          1.  Images are the same size
;          2.  Pedestal and dark current subtracted
;          3.  Images coaligned OR the /shift keyword set
;
;          The images may come in any order, and any combination
;          of two-three UV images will work (though some work 
;          better than others).
;
;          Don't normalize the image exposures.
;
; KEYWORD PARAMETERS:
;    shift  -- If set, coalign the image set prior to 
;              doing the analysis routine, using TR_GET_DISP.PRO.
;    debug  -- Gives small, less-than-useful hints as to what's 
;              going on.
;
; OUTPUTS:
;    iout    -- Index structure of output LyA image.
;    lya_out -- Computed LyA image, in units of DN.
;
;
; MODIFICATION HISTORY:
;    06-Dec-99 (BNH) - Written
;
;-
version = 1.0

; Constants
i2c_corr =  1.07
e_per_dn_a = 12.                ; Detector 'A'
e_per_dn_b = 42.                ; Detector 'B'
ss_1216 = where(index.wave_len eq '1216')
ss_1600 = where(index.wave_len eq '1600')

if (ss_1216[0] lt 0 or ss_1600[0] lt 0) then begin
  case 1 of 
      (ss_1216[0] lt 0): message, /info, 'No 1216 image passed.'
      (ss_1600[0] lt 0): message, /info, 'No 1600 image passed.'
  endcase
  message, 'One each 1216 and 1600 image required.  Failing.'
endif

; I don't know how to avoid doing this.  
d_temp = data[*,*,[ss_1216[0],ss_1600[0]]]

if keyword_set(shift) then $
  offset_1 = tr_get_disp(d_temp, /shift,debug=debug)

i1 = d_temp[*,*,0]/index[ss_1216].sht_mdur
i2 = d_temp[*,*,1]/index[ss_1600].sht_mdur
	
;; Smooth the 1600 data.
i2 = smooth(i2, 3)

iout = index[ss_1216]

if keyword_set(debug) then $
  message, /info, 'Data has been smoothed.'

; These are from (Handy et al. Solar Physics, 2000, in press.)]
; Pre-prints available at:
; http://lambic.physics.montana.edu/~handy/publications/lya_cal.ps
alpha =   0.972
beta  =  -0.105

dout = (alpha * i1) + (beta * i2)

iout.wave_len = 'LYA'

if keyword_set(debug) then $
  message, /info, 'Setting exposure (SHT_MDUR) to 1.0 seconds.'

iout.sht_mdur = 1.0

return
end
